"use strict";
var __classPrivateFieldSet = (this && this.__classPrivateFieldSet) || function (receiver, state, value, kind, f) {
    if (kind === "m") throw new TypeError("Private method is not writable");
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a setter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot write private member to an object whose class did not declare it");
    return (kind === "a" ? f.call(receiver, value) : f ? f.value = value : state.set(receiver, value)), value;
};
var __classPrivateFieldGet = (this && this.__classPrivateFieldGet) || function (receiver, state, kind, f) {
    if (kind === "a" && !f) throw new TypeError("Private accessor was defined without a getter");
    if (typeof state === "function" ? receiver !== state || !f : !state.has(receiver)) throw new TypeError("Cannot read private member from an object whose class did not declare it");
    return kind === "m" ? f : kind === "a" ? f.call(receiver) : f ? f.value : state.get(receiver);
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
var _Resource_resourceElement, _ResourceAttributes_resourceAttributesElement, _ResourceAttributes_resourceData;
Object.defineProperty(exports, "__esModule", { value: true });
exports.Resource = void 0;
const utils_1 = require("./utils");
const spark_md5_1 = __importDefault(require("spark-md5"));
const base64_arraybuffer_1 = require("base64-arraybuffer");
var MimeTypes;
(function (MimeTypes) {
    MimeTypes["GIF"] = "image/gif";
    MimeTypes["JPEG"] = "image/jpeg";
    MimeTypes["PNG"] = "image/png";
    MimeTypes["WAV"] = "audio/wav";
    MimeTypes["MPEG"] = "audio/mpeg";
    MimeTypes["PDF"] = "application/pdf";
    MimeTypes["INK"] = "application/vnd.evernote.ink";
})(MimeTypes || (MimeTypes = {}));
class Resource {
    constructor(resourceElement) {
        _Resource_resourceElement.set(this, void 0);
        __classPrivateFieldSet(this, _Resource_resourceElement, resourceElement, "f");
        this.validate();
    }
    get data() {
        const data = (0, utils_1.getAsString)(__classPrivateFieldGet(this, _Resource_resourceElement, "f"), "data");
        if (!data)
            throw new Error("data is required.");
        return data.replace(/\s+/gm, "");
    }
    get mime() {
        const mime = (0, utils_1.getAsString)(__classPrivateFieldGet(this, _Resource_resourceElement, "f"), "mime");
        if (!mime)
            throw new Error("mime is required.");
        return mime;
    }
    get width() {
        return (0, utils_1.getAsNumber)(__classPrivateFieldGet(this, _Resource_resourceElement, "f"), "width");
    }
    get height() {
        return (0, utils_1.getAsNumber)(__classPrivateFieldGet(this, _Resource_resourceElement, "f"), "height");
    }
    get duration() {
        return (0, utils_1.getAsNumber)(__classPrivateFieldGet(this, _Resource_resourceElement, "f"), "duration");
    }
    get alternateData() {
        return (0, utils_1.getAsString)(__classPrivateFieldGet(this, _Resource_resourceElement, "f"), "alternate-data");
    }
    get attributes() {
        const resourceAttributeElement = __classPrivateFieldGet(this, _Resource_resourceElement, "f").querySelector("resource-attributes");
        if (!resourceAttributeElement)
            return null;
        return new ResourceAttributes(this.data, resourceAttributeElement);
    }
    validate() {
        this.data && this.mime;
    }
}
exports.Resource = Resource;
_Resource_resourceElement = new WeakMap();
class ResourceAttributes {
    constructor(resourceData, resourceAttributesElement) {
        _ResourceAttributes_resourceAttributesElement.set(this, void 0);
        _ResourceAttributes_resourceData.set(this, void 0);
        __classPrivateFieldSet(this, _ResourceAttributes_resourceAttributesElement, resourceAttributesElement, "f");
        __classPrivateFieldSet(this, _ResourceAttributes_resourceData, resourceData, "f");
    }
    get latitude() {
        return (0, utils_1.getAsNumber)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "latitude");
    }
    get longitude() {
        return (0, utils_1.getAsNumber)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "longitude");
    }
    get altitude() {
        return (0, utils_1.getAsNumber)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "altitude");
    }
    get sourceUrl() {
        return (0, utils_1.getAsString)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "source-url");
    }
    get hash() {
        if (!__classPrivateFieldGet(this, _ResourceAttributes_resourceData, "f"))
            return null;
        return spark_md5_1.default.ArrayBuffer.hash((0, base64_arraybuffer_1.decode)(__classPrivateFieldGet(this, _ResourceAttributes_resourceData, "f")));
    }
    get cameraMake() {
        return (0, utils_1.getAsString)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "camera-make");
    }
    get cameraModel() {
        return (0, utils_1.getAsString)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "camera-model");
    }
    get recoType() {
        return (0, utils_1.getAsString)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "reco-type");
    }
    get filename() {
        return (0, utils_1.getAsString)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "file-name");
    }
    get attachment() {
        return (0, utils_1.getAsBoolean)(__classPrivateFieldGet(this, _ResourceAttributes_resourceAttributesElement, "f"), "attachment");
    }
}
_ResourceAttributes_resourceAttributesElement = new WeakMap(), _ResourceAttributes_resourceData = new WeakMap();
